@@ -33,7 +33,8 @@ pub fn const_modules(
 }
 
 fn parse_option(cm: &SourceMap, name: &str, src: String) -> Arc<Expr> {
-    static CACHE: Lazy<DashMap<String, Arc<Expr>>> = Lazy::new(|| DashMap::default());
+    static CACHE: Lazy<DashMap<String, Arc<Expr>, ahash::RandomState>> =
+        Lazy::new(|| DashMap::default());
 
     let fm = cm.new_source_file(FileName::Custom(format!("<const-module-{}.js>", name)), src);
     if let Some(expr) = CACHE.get(&**fm.src) {
